@@ -382,7 +382,7 @@ Related options:
     cfg.BoolOpt('cinder_use_multipath',
                 default=False,
                 help="""
-Flag to identify mutipath is supported or not in the deployment.
+Flag to identify multipath is supported or not in the deployment.
 
 Set it to False if multipath is not supported.
 
@@ -532,7 +532,7 @@ class Store(glance_store.driver.Store):
                     return True
         except Exception:
             # Glance calls this method to update legacy images URL
-            # If an exception occours due to image/volume is non-existent or
+            # If an exception occurs due to image/volume is non-existent or
             # any other reason, we return False (i.e. the image location URL
             # won't be updated) and it is glance's responsibility to handle
             # the case when the image failed to update
@@ -748,7 +748,6 @@ class Store(glance_store.driver.Store):
         attachment = self.volume_api.attachment_update(
             client, attachment['id'], connector_prop,
             mountpoint='glance_store')
-        self.volume_api.attachment_complete(client, attachment.id)
         volume = volume.manager.get(volume_id)
         connection_info = attachment.connection_info
 
@@ -789,6 +788,10 @@ class Store(glance_store.driver.Store):
                 device = connect_volume_nfs()
             else:
                 device = conn.connect_volume(connection_info)
+
+            # Complete the attachment (marking the volume "in-use") after
+            # the connection with os-brick is complete
+            self.volume_api.attachment_complete(client, attachment.id)
             if (connection_info['driver_volume_type'] == 'rbd' and
                not conn.do_local_attach):
                 yield device['path']
@@ -959,17 +962,10 @@ class Store(glance_store.driver.Store):
             LOG.info(_LI("Since image size is zero, we will be doing "
                          "resize-before-write for each GB which "
                          "will be considerably slower than normal."))
-        try:
-            volume = self.volume_api.create(client, size_gb, name=name,
-                                            metadata=metadata,
-                                            volume_type=volume_type)
-        except cinder_exception.NotFound:
-            LOG.error(_LE("Invalid volume type %s configured. Please check "
-                          "the `cinder_volume_type` configuration parameter."
-                          % volume_type))
-            msg = (_("Failed to create image-volume due to invalid "
-                     "`cinder_volume_type` configured."))
-            raise exceptions.BackendException(msg)
+
+        volume = self.volume_api.create(client, size_gb, name=name,
+                                        metadata=metadata,
+                                        volume_type=volume_type)
 
         volume = self._wait_volume_status(volume, 'creating', 'available')
         size_gb = volume.size
